
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.011.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Feature-rich REST controller for use with ExtJS",
  "dist_author" => [
    "Moritz Onken <onken\@netcubed.de>"
  ],
  "dist_name" => "CatalystX-ExtJS-REST",
  "dist_version" => "2.1.3",
  "license" => "bsd",
  "module_name" => "CatalystX::ExtJS::REST",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Catalyst::Action::REST" => "0.88",
    "Catalyst::Action::RenderView" => 0,
    "Catalyst::Runtime" => "5.80024",
    "CatalystX::ExtJS::Direct" => "v2.1.5",
    "DBIx::Class" => "0.08127",
    "HTML::Entities" => 0,
    "HTML::FormFu::ExtJS" => 0,
    "HTML::FormFu::Model::DBIC" => "0.08",
    "JavaScript::Dumper" => "0.011",
    "Lingua::EN::Inflect" => 0,
    "Moose" => "1.21",
    "Path::Class" => 0,
    "Try::Tiny" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "Test::More" => "0.88"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.3601",
  "Test::More" => "0.88"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
